@@ -121,7 +121,7 @@ use warnings;
 
 use base qw{Astro::Coord::ECI::TLE};
 
-our $VERSION = '0.070_02';
+our $VERSION = '0.071_01';
 
 use Astro::Coord::ECI::Sun;
 use Astro::Coord::ECI::Utils qw{:all};
@@ -508,8 +508,8 @@ sub flare {
     return $self->$method (@args);
 }
 
-
-sub _flare_fixed {
+# Called as $self->$method()
+sub _flare_fixed {	## no critic (ProhibitUnusedPrivateSubroutines)
     my $self = shift;
     my $station = shift;
     {
@@ -1469,7 +1469,8 @@ sub reflection {
 }
 
 
-sub _reflection_fixed {
+# Called as $self->$method, above
+sub _reflection_fixed {	## no critic (ProhibitUnusedPrivateSubroutines)
     my ( $self, $station, $time ) = @_;
     defined $time
 	or $time = $self->universal();
@@ -1606,7 +1607,8 @@ sub __parse_name {
     $encode_status[STATUS_TUMBLING]	= '-';
 
     sub __encode_operational_status {
-	my ( $self, $name, $status ) = @_;
+##	my ( $self, $name, $status ) = @_;
+	my ( $self, undef, $status ) = @_;	# Name unused
 	defined $status
 	    or $status = $self->get( 'status' );
 	defined $encode_status[ $status ]
